Changelog
=========

2.0 (2023-02-02)
----------------

- Drop support for Python 2.7, 3.5, 3.6.


1.2 (2022-06-27)
----------------

- Added support for Python 3.9 and 3.10

- Switched to GitHub Actions for CI
  (`#2 <https://github.com/dataflake/dataflake.wsgi.bjoern/issues/2>`_)


1.1 (2019-08-14)
----------------

- Added the ``listen`` parameter to pass a port or a host and port.
  This is more in line with what ``plone.recipe.zope2instance`` expects.


1.0 (2019-04-20)
----------------

- Initial release
